"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.get_connectors = void 0;
const zod_1 = require("zod");
const tool_js_1 = require("../../tool.js");
const util_js_1 = require("../../util.js");
const client = require("../../../dataconnect/client.js");
const fileUtils_js_1 = require("../../../dataconnect/fileUtils.js");
const converter_js_1 = require("./converter.js");
exports.get_connectors = (0, tool_js_1.tool)({
    name: "get_connectors",
    description: "Get the Firebase Data Connect Connectors in the project, which includes the pre-defined GraphQL queries accessible to client SDKs.",
    inputSchema: zod_1.z.object({
        service_id: zod_1.z
            .string()
            .nullable()
            .describe("The Firebase Data Connect service ID to look for. If there is only one service defined in firebase.json, this can be omitted and that will be used."),
    }),
    annotations: {
        title: "Get Data Connect Connectors",
        readOnlyHint: true,
    },
    _meta: {
        requiresProject: true,
        requiresAuth: true,
    },
}, async ({ service_id }, { projectId, config }) => {
    const serviceInfo = await (0, fileUtils_js_1.pickService)(projectId, config, service_id || undefined);
    const connectors = await client.listConnectors(serviceInfo.serviceName, ["*"]);
    return (0, util_js_1.toContent)(connectors.map(converter_js_1.connectorToText).join("\n\n"));
});
